@@ -9,15 +9,14 @@ log = logging.getLogger(__name__)
 
 class TestingFileList(FileList):
     """File list for testing."""
-    __module__ = 'pyobs.vfs.filelists'
+
+    __module__ = "pyobs.vfs.filelists"
 
     def __init__(self, *args: Any, **kwargs: Any):
         pass
 
     def __call__(self, filename: str) -> List[str]:
-        return [
-            __file__
-        ]
+        return [__file__]
 
 
-__all__ = ['TestingFileList']
+__all__ = ["TestingFileList"]
